==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_functions/mp0111_001/MP0111_DeleteComments_001.java <==

package net.datastream.schemas.mp_functions.mp0111_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ENTITYCOMMENTID_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYCOMMENTID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="is_gis_webservice_request" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Delete" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="Comments" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "entitycommentid"
})
@XmlRootElement(name = "MP0111_DeleteComments_001")
public class MP0111_DeleteComments_001 {

    @XmlElement(name = "ENTITYCOMMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ENTITYCOMMENTID_Type entitycommentid;
    @XmlAttribute(name = "is_gis_webservice_request")
    protected String is_Gis_Webservice_Request;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Obtient la valeur de la propriété entitycommentid.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYCOMMENTID_Type }
     *     
     */
    public ENTITYCOMMENTID_Type getENTITYCOMMENTID() {
        return entitycommentid;
    }

    /**
     * Définit la valeur de la propriété entitycommentid.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYCOMMENTID_Type }
     *     
     */
    public void setENTITYCOMMENTID(ENTITYCOMMENTID_Type value) {
        this.entitycommentid = value;
    }

    /**
     * Obtient la valeur de la propriété is_Gis_Webservice_Request.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Gis_Webservice_Request() {
        if (is_Gis_Webservice_Request == null) {
            return "false";
        } else {
            return is_Gis_Webservice_Request;
        }
    }

    /**
     * Définit la valeur de la propriété is_Gis_Webservice_Request.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Gis_Webservice_Request(String value) {
        this.is_Gis_Webservice_Request = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.DELETE;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.COMMENTS;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_functions/mp0111_001/MP0111_DeleteComments_001.java <==

package net.datastream.schemas.mp_functions.mp0111_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ENTITYCOMMENTID_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYCOMMENTID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="is_gis_webservice_request" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Delete" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="Comments" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "entitycommentid"
})
@XmlRootElement(name = "MP0111_DeleteComments_001")
public class MP0111_DeleteComments_001 {

    @XmlElement(name = "ENTITYCOMMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ENTITYCOMMENTID_Type entitycommentid;
    @XmlAttribute(name = "is_gis_webservice_request")
    protected String is_Gis_Webservice_Request;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the entitycommentid property.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYCOMMENTID_Type }
     *     
     */
    public ENTITYCOMMENTID_Type getENTITYCOMMENTID() {
        return entitycommentid;
    }

    /**
     * Sets the value of the entitycommentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYCOMMENTID_Type }
     *     
     */
    public void setENTITYCOMMENTID(ENTITYCOMMENTID_Type value) {
        this.entitycommentid = value;
    }

    /**
     * Gets the value of the is_Gis_Webservice_Request property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Gis_Webservice_Request() {
        if (is_Gis_Webservice_Request == null) {
            return "false";
        } else {
            return is_Gis_Webservice_Request;
        }
    }

    /**
     * Sets the value of the is_Gis_Webservice_Request property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Gis_Webservice_Request(String value) {
        this.is_Gis_Webservice_Request = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.DELETE;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.COMMENTS;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
